pub struct RunTexts { /* private fields */ }Expand description
Run texts by key. When two runs share a key but not a text (only possible when two code points share a glyph and everything else about the runs matches), the first recorded wins: record in document order.
Implementations